@@ -14,7 +14,7 @@ sub do_convert_all_param
 {
     my $self    = shift;
     my $strings = shift;
-    return Jcode->new($strings)->euc;
+    return Jcode->new($strings)->h2z->euc;
 }
 
 1;
