@@ -8,7 +8,7 @@ sub do_convert_on_get
 {
     my $self    = shift;
     my $strings = shift;
-    return Jcode->new($strings)->utf8;
+    return Jcode->new($strings)->h2z->utf8;
 }
 
 1;
